Class: Zxcvbn::Match
- Inherits:
-
Data
- Object
- Data
- Zxcvbn::Match
- Defined in:
- lib/zxcvbn/match.rb
Overview
A substring match found by one of the pattern matchers.
All attributes are optional and default to nil. Use #with to derive a new match with changed attributes.
Instance Attribute Summary collapse
-
#ascending ⇒ Object
readonly
Returns the value of attribute ascending.
-
#base_guesses ⇒ Object
readonly
Returns the value of attribute base_guesses.
-
#base_token ⇒ Object
readonly
Returns the value of attribute base_token.
-
#day ⇒ Object
readonly
Returns the value of attribute day.
-
#dictionary_name ⇒ Object
readonly
Returns the value of attribute dictionary_name.
-
#graph ⇒ Object
readonly
Returns the value of attribute graph.
-
#guesses ⇒ Object
readonly
Returns the value of attribute guesses.
-
#guesses_log10 ⇒ Object
readonly
Returns the value of attribute guesses_log10.
-
#i ⇒ Object
readonly
Returns the value of attribute i.
-
#j ⇒ Object
readonly
Returns the value of attribute j.
-
#l33t ⇒ Object
readonly
Returns the value of attribute l33t.
-
#l33t_variations ⇒ Object
readonly
Returns the value of attribute l33t_variations.
-
#matched_word ⇒ Object
readonly
Returns the value of attribute matched_word.
-
#month ⇒ Object
readonly
Returns the value of attribute month.
-
#pattern ⇒ Object
readonly
Returns the value of attribute pattern.
-
#rank ⇒ Object
readonly
Returns the value of attribute rank.
-
#repeat_count ⇒ Object
readonly
Returns the value of attribute repeat_count.
-
#reversed ⇒ Object
readonly
Returns the value of attribute reversed.
-
#separator ⇒ Object
readonly
Returns the value of attribute separator.
-
#sequence_name ⇒ Object
readonly
Returns the value of attribute sequence_name.
-
#sequence_space ⇒ Object
readonly
Returns the value of attribute sequence_space.
-
#shifted_count ⇒ Object
readonly
Returns the value of attribute shifted_count.
-
#sub ⇒ Object
readonly
Returns the value of attribute sub.
-
#sub_display ⇒ Object
readonly
Returns the value of attribute sub_display.
-
#token ⇒ Object
readonly
Returns the value of attribute token.
-
#turns ⇒ Object
readonly
Returns the value of attribute turns.
-
#uppercase_variations ⇒ Object
readonly
Returns the value of attribute uppercase_variations.
-
#year ⇒ Object
readonly
Returns the value of attribute year.
Instance Method Summary collapse
-
#initialize(pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil) ⇒ Match
constructor
A new instance of Match.
-
#inspect ⇒ String
A human-readable representation omitting nil fields and token.
- #pretty_print(pp) ⇒ void
Constructor Details
#initialize(pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil) ⇒ Match
Returns a new instance of Match.
73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zxcvbn/match.rb', line 73 def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end |
Instance Attribute Details
#ascending ⇒ Object (readonly)
Returns the value of attribute ascending
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#base_guesses ⇒ Object (readonly)
Returns the value of attribute base_guesses
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#base_token ⇒ Object (readonly)
Returns the value of attribute base_token
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#day ⇒ Object (readonly)
Returns the value of attribute day
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#dictionary_name ⇒ Object (readonly)
Returns the value of attribute dictionary_name
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#graph ⇒ Object (readonly)
Returns the value of attribute graph
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#guesses ⇒ Object (readonly)
Returns the value of attribute guesses
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#guesses_log10 ⇒ Object (readonly)
Returns the value of attribute guesses_log10
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#i ⇒ Object (readonly)
Returns the value of attribute i
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#j ⇒ Object (readonly)
Returns the value of attribute j
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#l33t ⇒ Object (readonly)
Returns the value of attribute l33t
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#l33t_variations ⇒ Object (readonly)
Returns the value of attribute l33t_variations
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#matched_word ⇒ Object (readonly)
Returns the value of attribute matched_word
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#month ⇒ Object (readonly)
Returns the value of attribute month
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#pattern ⇒ Object (readonly)
Returns the value of attribute pattern
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#rank ⇒ Object (readonly)
Returns the value of attribute rank
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#repeat_count ⇒ Object (readonly)
Returns the value of attribute repeat_count
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#reversed ⇒ Object (readonly)
Returns the value of attribute reversed
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#separator ⇒ Object (readonly)
Returns the value of attribute separator
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#sequence_name ⇒ Object (readonly)
Returns the value of attribute sequence_name
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#sequence_space ⇒ Object (readonly)
Returns the value of attribute sequence_space
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#shifted_count ⇒ Object (readonly)
Returns the value of attribute shifted_count
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#sub ⇒ Object (readonly)
Returns the value of attribute sub
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#sub_display ⇒ Object (readonly)
Returns the value of attribute sub_display
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#token ⇒ Object (readonly)
Returns the value of attribute token
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#turns ⇒ Object (readonly)
Returns the value of attribute turns
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#uppercase_variations ⇒ Object (readonly)
Returns the value of attribute uppercase_variations
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
#year ⇒ Object (readonly)
Returns the value of attribute year
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zxcvbn/match.rb', line 66 Match = ::Data.define( :pattern, :i, :j, :token, :matched_word, :rank, :dictionary_name, :reversed, :l33t, :sub, :sub_display, :guesses, :guesses_log10, :base_guesses, :uppercase_variations, :l33t_variations, :base_token, :repeat_count, :sequence_name, :sequence_space, :ascending, :graph, :turns, :shifted_count, :year, :month, :day, :separator ) do def initialize( pattern: nil, i: nil, j: nil, token: nil, matched_word: nil, rank: nil, dictionary_name: nil, reversed: nil, l33t: nil, sub: nil, sub_display: nil, guesses: nil, guesses_log10: nil, base_guesses: nil, uppercase_variations: nil, l33t_variations: nil, base_token: nil, repeat_count: nil, sequence_name: nil, sequence_space: nil, ascending: nil, graph: nil, turns: nil, shifted_count: nil, year: nil, month: nil, day: nil, separator: nil ) super end # @return [String] a human-readable representation omitting nil fields and token def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end # @param pp [PP] the pretty-printer instance # @return [void] def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end end |
Instance Method Details
#inspect ⇒ String
Returns a human-readable representation omitting nil fields and token.
86 87 88 89 |
# File 'lib/zxcvbn/match.rb', line 86 def inspect fields = to_h.reject { |k, v| v.nil? || k == :token }.map { |k, v| "#{k}=#{v.inspect}" }.join(', ') "#<data #{self.class} #{fields}>" end |
#pretty_print(pp) ⇒ void
This method returns an undefined value.
93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/zxcvbn/match.rb', line 93 def pretty_print(pp) fields = to_h.reject { |_, v| v.nil? } pp.group(1, "#<data #{self.class}", '>') do fields.each_with_index do |(k, v), i| pp.text(',') if i.positive? pp.breakable ' ' pp.text("#{k}=") v.pretty_print(pp) end end end |